@@ -201,20 +201,26 @@ class DDataPlotter(Ui_DDataPlotter, QWidget):
             try:
                 x_float = float(self.ax.get_xticklabels()[-1]._text)
                 X_str = format(x, ".4g")
-                Y_str = format(y, ".4g")
             except:
                 X_str = None
-                Y_str = None
                 for ticklabel in self.ax.get_xticklabels():
                     if ticklabel._x == x:
                         X_str = ticklabel._text
                         break
-                for ticklabel in self.ax.get_yticklabels():
-                    if ticklabel._y == y:
-                        Y_str = ticklabel._text
-                        break
-                if X_str is None or Y_str is None:
-                    return ""
+            if "mathdefault" in self.ax.get_yticklabels()[-1]._text:
+                Y_str = format(y, ".4g")
+            else:
+                try:
+                    y_float = float(self.ax.get_yticklabels()[-1]._text)
+                    Y_str = format(y, ".4g")
+                except:
+                    Y_str = None
+                    for ticklabel in self.ax.get_yticklabels():
+                        if ticklabel._y == y:
+                            Y_str = ticklabel._text
+                            break
+            if X_str is None or Y_str is None:
+                return ""
 
             # Recovering the input of the user
             [
@@ -243,10 +249,10 @@ class DDataPlotter(Ui_DDataPlotter, QWidget):
                 yunit = "[" + latex(axes_selected_parsed[1].unit) + "]"
 
             else:
-                ylabel = self.data.symbol
-
-                if self.data._name.lower() in SYMBOL_DICT:
-                    ylabel = latex(SYMBOL_DICT[self.data._name.lower()])
+                if self.data.name.lower() in SYMBOL_DICT:
+                    ylabel = latex(SYMBOL_DICT[self.data.name.lower()])
+                else:
+                    ylabel = latex(self.data.symbol)
 
                 yunit = "[" + latex(self.data.unit) + "]"
 
@@ -297,12 +303,17 @@ class DDataPlotter(Ui_DDataPlotter, QWidget):
         def set_cursor(event):
             plot_obj = event.artist
             Z = None
+            legend = None
             if isinstance(plot_obj, Line2D):
                 ind = event.ind
                 xdata = plot_obj.get_xdata()
                 ydata = plot_obj.get_ydata()
                 X = xdata[ind][0]  # X position of the click
                 Y = ydata[ind][0]  # Y position of the click
+                if self.fig.legend() not in [None, []]:
+                    legend = (
+                        self.fig.legend().texts[self.ax.lines.index(plot_obj)]._text
+                    )
             elif isinstance(plot_obj, PathCollection):
                 ind = event.ind
                 X = plot_obj.get_offsets().data[ind][0][0]
@@ -339,48 +350,51 @@ class DDataPlotter(Ui_DDataPlotter, QWidget):
             dx = (x_max - x_min) / 50
             if X is not None and Y is not None:
                 label = format_coord(X, Y, Z, sep="\n")
-                if self.text is None:
-                    # Create label in box and black cross
-                    self.text = self.ax.text(
-                        X + dx,
-                        Y,
-                        label,
-                        ha="left",
-                        va="center",
-                        bbox=text_box,
-                    )
-                    # Draw line
-                    self.line = self.ax.plot(
-                        [X, X + dx],
-                        [Y, Y],
-                        color="k",
-                        linestyle="-",
-                        linewidth=0.5,
-                    )
-                    # Draw circle
-                    self.circle = self.ax.plot(
-                        X,
-                        Y,
-                        ".",
-                        markerfacecolor="w",
-                        markeredgecolor="k",
-                        markeredgewidth=0.5,
-                        markersize=12,
-                    )
-                else:
-                    # Update label, line and circle
-                    self.text._x = X + dx
-                    self.text._y = Y
-                    self.text._text = label
-                    self.circle[0].set_xdata(array(X))
-                    self.circle[0].set_ydata(array(Y))
-                    self.line[0].set_xdata(array([X, X + dx]))
-                    self.line[0].set_ydata(array([Y, Y]))
+                if legend is not None:
+                    label = legend + "\n" + label
+                if label != "":
+                    if self.text is None:
+                        # Create label in box and black cross
+                        self.text = self.ax.text(
+                            X + dx,
+                            Y,
+                            label,
+                            ha="left",
+                            va="center",
+                            bbox=text_box,
+                        )
+                        # Draw line
+                        self.line = self.ax.plot(
+                            [X, X + dx],
+                            [Y, Y],
+                            color="k",
+                            linestyle="-",
+                            linewidth=0.5,
+                        )
+                        # Draw circle
+                        self.circle = self.ax.plot(
+                            X,
+                            Y,
+                            ".",
+                            markerfacecolor="w",
+                            markeredgecolor="k",
+                            markeredgewidth=0.5,
+                            markersize=12,
+                        )
+                    else:
+                        # Update label, line and circle
+                        self.text._x = X + dx
+                        self.text._y = Y
+                        self.text._text = label
+                        self.circle[0].set_xdata(array(X))
+                        self.circle[0].set_ydata(array(Y))
+                        self.line[0].set_xdata(array([X, X + dx]))
+                        self.line[0].set_ydata(array([Y, Y]))
 
-            self.ax.texts[-1].set_visible(True)
-            self.ax.lines[-1].set_visible(True)
-            self.ax.lines[-2].set_visible(True)
-            self.canvas.draw()
+                    self.ax.texts[-1].set_visible(True)
+                    self.ax.lines[-1].set_visible(True)
+                    self.ax.lines[-2].set_visible(True)
+                    self.canvas.draw()
 
         def delete_cursor(event):
             if event.button.name == "RIGHT":
